# `Ramses`
[![Documentation Status](https://readthedocs.org/projects/ramses/badge/?version=latest)](https://readthedocs.org/projects/ramses/?badge=latest)

Generate a RESTful API for Pyramid using [RAML](http://raml.org). It uses [Nefertari](https://github.com/brandicted/nefertari) which provides ElasticSearch-powered views.

You can read the documentation on [readthedocs](https://ramses.readthedocs.org/en/latest/).
